.. cppcolormap documentation master file, created by
   sphinx-quickstart on Fri Feb 12 17:31:49 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

cppcolormap
===========

.. toctree::
   :caption: API
   :maxdepth: 1

   api_cpp.rst
   api_python.rst

.. toctree::
   :caption: DEVELOP
   :maxdepth: 1

   changelog.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
